@@ -218,7 +218,12 @@ class BibItem(dict):
     """
     
     first=''
-    for d in auth[A_FIRST].split():
+    try:
+      aa=auth[A_FIRST].split()
+    except:
+      print auth
+      sys.exit()
+    for d in aa:
       if Initial or len(d)==1:
         first += d[0]+'.'
       else:
@@ -250,6 +255,13 @@ class BibItem(dict):
   def get_first_author(self):
     return self.get_authorsList(format=1,Initial=True)[0]
     
+  def get_editors(self):
+    aa= self.get_authorsList(format=0,Initial=False)
+    if len(aa)== 1:
+      return aa[0]
+    else: 
+      return ', '.join(aa[:-1])+ ' and ' + aa[-1]
+    
   def get_authors(self, Initial=False, smart=False):
     """
     Returns a string with the authors in the form:
@@ -285,6 +297,8 @@ class BibItem(dict):
       return self.key
     elif field == 'author':
       return self.get_authors()
+    elif field == 'editor':
+      return self.get_editors()
     elif field == 'affiliation':
       return self.get_affiliation()
     elif field == 'pages':
@@ -315,7 +329,7 @@ class BibItem(dict):
     # Add list of authors
     for f in ['author','editor']:
       if self.has_key(f):
-        autores= ' and '.join(self.get_authorsList(format=1))
+        autores= ' and '.join(self.get_authorsList(format=1,who=f))
         wrap.initial_indent=initial_indent
         s+= wrap.fill(f + ' = {' + autores +'},') + '\n'
     # Some fields that are copied literally
